@@ -73,8 +73,8 @@ static const char * event_desc[EVENT_MAX] = {
     [EVENT_PAUSE] = N_("Pause/Resume"),
     [EVENT_STOP] = N_("Stop"),
     [EVENT_NEXT_TRACK] = N_("Next track"),
-    [EVENT_FORWARD] = N_("Forward 5 seconds"),
-    [EVENT_BACKWARD] = N_("Rewind 5 seconds"),
+    [EVENT_FORWARD] = N_("Step forward"),
+    [EVENT_BACKWARD] = N_("Step backward"),
     [EVENT_MUTE] = N_("Mute"),
     [EVENT_VOL_UP] = N_("Volume up"),
     [EVENT_VOL_DOWN] = N_("Volume down"),
